@@ -1,38 +1,36 @@
 # -*- coding: UTF-8 -*-
+#
+# Copyright © 2003 - 2015 Michal Čihař <michal@cihar.com>
+#
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published by
+# the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+#
 # vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 About dialog
 '''
-__author__ = 'Michal Čihař'
-__email__ = 'michal@cihar.com'
-__license__ = '''
-Copyright © 2003 - 2010 Michal Čihař
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License version 2 as published by
-the Free Software Foundation.
-
-This program is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
-more details.
-
-You should have received a copy of the GNU General Public License along with
-this program; if not, write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-'''
 
 import wx
 import wx.html
 import wx.lib.wxpTag
 import sys
 import Wammu
-if Wammu.gammu_error == None:
+if Wammu.gammu_error is None:
     import gammu
 import Wammu.Utils
 import Wammu.Paths
-from Wammu.Locales import hgettext as _, HtmlStrConv
+from Wammu.Locales import ugettext as _
 
 class AboutBox(wx.Dialog):
     '''
@@ -94,11 +92,10 @@ cellpadding="0" border="1">
             Wammu.__version__,
             _('Running on Python %s') % sys.version.split()[0],
             _('Using wxPython %s') % wx.VERSION_STRING,
-            _('Using python-gammu %(python_gammu_version)s and Gammu %(gammu_version)s') %
-                {
-                    'python_gammu_version':gammu.Version()[1],
-                    'gammu_version': gammu.Version()[0]
-                }),
+            _('Using python-gammu %(python_gammu_version)s and Gammu %(gammu_version)s') % {
+                'python_gammu_version': gammu.Version()[1],
+                'gammu_version': gammu.Version()[0]
+            }),
             _('<b>Wammu</b> is a wxPython based GUI for Gammu.'),
             copyrightline,
             _('''
@@ -113,12 +110,14 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 '''))
 
-        html = wx.html.HtmlWindow(self, -1, size = (500, -1))
+        html = wx.html.HtmlWindow(self, -1, size=(500, -1))
         html.SetPage(text)
         btn = html.FindWindowById(wx.ID_OK)
-        if btn != None:
+        if btn is not None:
             btn.SetDefault()
         representation = html.GetInternalRepresentation()
-        html.SetSize( (representation.GetWidth()+25, representation.GetHeight()+25) )
+        html.SetSize(
+            (representation.GetWidth() + 25, representation.GetHeight() + 25)
+        )
         self.SetClientSize(html.GetSize())
         self.CentreOnParent(wx.BOTH)
