@@ -1,27 +1,25 @@
 # -*- coding: UTF-8 -*-
+#
+# Copyright © 2003 - 2015 Michal Čihař <michal@cihar.com>
+#
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published by
+# the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+#
 # vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 Items browser
 '''
-__author__ = 'Michal Čihař'
-__email__ = 'michal@cihar.com'
-__license__ = '''
-Copyright © 2003 - 2010 Michal Čihař
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License version 2 as published by
-the Free Software Foundation.
-
-This program is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
-more details.
-
-You should have received a copy of the GNU General Public License along with
-this program; if not, write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-'''
 
 import wx
 import re
@@ -29,7 +27,7 @@ import Wammu
 import Wammu.Events
 import Wammu.Utils
 import Wammu.Paths
-from Wammu.Locales import StrConv
+from Wammu.Locales import StrConv, ugettext as _
 
 import wx.lib.mixins.listctrl
 
@@ -134,6 +132,7 @@ COLUMN_INFO = {
         )
 }
 
+
 class FilterException(Exception):
     '''
     Exception which occurs when there is something wrong in filtering
@@ -141,18 +140,18 @@ class FilterException(Exception):
     '''
     pass
 
+
 class Browser(wx.ListCtrl, wx.lib.mixins.listctrl.ListCtrlAutoWidthMixin):
     '''
     Generic class for browsing values.
     '''
     def __init__(self, parent, win, cfg):
-        wx.ListCtrl.__init__(self,
-                parent,
-                -1,
-                style = wx.LC_REPORT |
-                    wx.LC_VIRTUAL |
-                    wx.LC_HRULES |
-                    wx.LC_VRULES)
+        wx.ListCtrl.__init__(
+            self,
+            parent,
+            -1,
+            style=wx.LC_REPORT | wx.LC_VIRTUAL | wx.LC_HRULES | wx.LC_VRULES
+        )
         self.win = win
         self.cfg = cfg
 
@@ -192,77 +191,110 @@ class Browser(wx.ListCtrl, wx.lib.mixins.listctrl.ListCtrlAutoWidthMixin):
         wx.lib.mixins.listctrl.ListCtrlAutoWidthMixin.__init__(self)
 
         # Create IDs for popup menu
-        self.popup_id_send        = wx.NewId()
-        self.popup_id_edit        = wx.NewId()
-        self.popup_id_message     = wx.NewId()
-        self.popup_id_contact     = wx.NewId()
-        self.popup_id_call        = wx.NewId()
-        self.popup_id_delete      = wx.NewId()
-        self.popup_id_delete_selection   = wx.NewId()
-        self.popup_id_duplicate   = wx.NewId()
-        self.popup_id_reply       = wx.NewId()
-        self.popup_id_backup_one   = wx.NewId()
-        self.popup_id_backup_selection   = wx.NewId()
-        self.popup_id_backup_all   = wx.NewId()
+        self.popup_id_send = wx.NewId()
+        self.popup_id_edit = wx.NewId()
+        self.popup_id_message = wx.NewId()
+        self.popup_id_contact = wx.NewId()
+        self.popup_id_call = wx.NewId()
+        self.popup_id_delete = wx.NewId()
+        self.popup_id_delete_selection = wx.NewId()
+        self.popup_id_duplicate = wx.NewId()
+        self.popup_id_reply = wx.NewId()
+        self.popup_id_backup_one = wx.NewId()
+        self.popup_id_backup_selection = wx.NewId()
+        self.popup_id_backup_all = wx.NewId()
 
         self.BindEvents()
 
-
     def BindEvents(self):
         '''
         Bind various event handlers to events we need.
         '''
-        self.Bind(wx.EVT_LIST_ITEM_SELECTED,
-                self.OnItemSelected,
-                self)
-        self.Bind(wx.EVT_LIST_ITEM_ACTIVATED,
-                self.OnItemActivated,
-                self)
-        self.Bind(wx.EVT_LIST_KEY_DOWN,
-                self.OnKey,
-                self)
-        self.Bind(wx.EVT_LIST_COL_CLICK,
-                self.OnColClick,
-                self)
-        self.Bind(wx.EVT_LIST_ITEM_RIGHT_CLICK,
-                self.OnRightClick,
-                self)
-        self.Bind(wx.EVT_MENU,
-                self.OnPopupSend,
-                id = self.popup_id_send)
-        self.Bind(wx.EVT_MENU,
-                self.OnPopupEdit,
-                id = self.popup_id_edit)
-        self.Bind(wx.EVT_MENU,
-                self.OnPopupMessage,
-                id = self.popup_id_message)
-        self.Bind(wx.EVT_MENU,
-                self.OnPopupContact,
-                id = self.popup_id_contact)
-        self.Bind(wx.EVT_MENU,
-                self.OnPopupCall,
-                id = self.popup_id_call)
-        self.Bind(wx.EVT_MENU,
-                self.OnPopupDelete,
-                id = self.popup_id_delete)
-        self.Bind(wx.EVT_MENU,
-                self.OnPopupDeleteSel,
-                id = self.popup_id_delete_selection)
-        self.Bind(wx.EVT_MENU,
-                self.OnPopupDuplicate,
-                id = self.popup_id_duplicate)
-        self.Bind(wx.EVT_MENU,
-                self.OnPopupReply,
-                id = self.popup_id_reply)
-        self.Bind(wx.EVT_MENU,
-                self.OnPopupBackupOne,
-                id = self.popup_id_backup_one)
-        self.Bind(wx.EVT_MENU,
-                self.OnPopupBackupSel,
-                id = self.popup_id_backup_selection)
-        self.Bind(wx.EVT_MENU,
-                self.OnPopupBackupAll,
-                id = self.popup_id_backup_all)
+        self.Bind(
+            wx.EVT_LIST_ITEM_SELECTED,
+            self.OnItemSelected,
+            self
+        )
+        self.Bind(
+            wx.EVT_LIST_ITEM_ACTIVATED,
+            self.OnItemActivated,
+            self
+        )
+        self.Bind(
+            wx.EVT_LIST_KEY_DOWN,
+            self.OnKey,
+            self
+        )
+        self.Bind(
+            wx.EVT_LIST_COL_CLICK,
+            self.OnColClick,
+            self
+        )
+        self.Bind(
+            wx.EVT_LIST_ITEM_RIGHT_CLICK,
+            self.OnRightClick,
+            self
+        )
+        self.Bind(
+            wx.EVT_MENU,
+            self.OnPopupSend,
+            id=self.popup_id_send
+        )
+        self.Bind(
+            wx.EVT_MENU,
+            self.OnPopupEdit,
+            id=self.popup_id_edit
+        )
+        self.Bind(
+            wx.EVT_MENU,
+            self.OnPopupMessage,
+            id=self.popup_id_message
+        )
+        self.Bind(
+            wx.EVT_MENU,
+            self.OnPopupContact,
+            id=self.popup_id_contact
+        )
+        self.Bind(
+            wx.EVT_MENU,
+            self.OnPopupCall,
+            id=self.popup_id_call
+        )
+        self.Bind(
+            wx.EVT_MENU,
+            self.OnPopupDelete,
+            id=self.popup_id_delete
+        )
+        self.Bind(
+            wx.EVT_MENU,
+            self.OnPopupDeleteSel,
+            id=self.popup_id_delete_selection
+        )
+        self.Bind(
+            wx.EVT_MENU,
+            self.OnPopupDuplicate,
+            id=self.popup_id_duplicate
+        )
+        self.Bind(
+            wx.EVT_MENU,
+            self.OnPopupReply,
+            id=self.popup_id_reply
+        )
+        self.Bind(
+            wx.EVT_MENU,
+            self.OnPopupBackupOne,
+            id=self.popup_id_backup_one
+        )
+        self.Bind(
+            wx.EVT_MENU,
+            self.OnPopupBackupSel,
+            id=self.popup_id_backup_selection
+        )
+        self.Bind(
+            wx.EVT_MENU,
+            self.OnPopupBackupAll,
+            id=self.popup_id_backup_all
+        )
 
     def ShowHeaders(self):
         '''
@@ -285,13 +317,13 @@ class Browser(wx.ListCtrl, wx.lib.mixins.listctrl.ListCtrlAutoWidthMixin):
         for i in range(cnt):
             size = self.GetTextExtent(StrConv(self.columns[i]))[0]
             # 16 bellow is for sort arrrow
-            if (size + 16 > maxval[i]):
+            if size + 16 > maxval[i]:
                 maxval[i] = size + 16
 
         for current in self.values:
             for i in range(cnt):
                 size = self.GetTextExtent(StrConv(current[self.keys[i]]))
-                if (size[0] > maxval[i]):
+                if size[0] > maxval[i]:
                     maxval[i] = size[0]
         for i in range(cnt - 1):
             self.SetColumnWidth(i, maxval[i] + spc)
@@ -324,8 +356,10 @@ class Browser(wx.ListCtrl, wx.lib.mixins.listctrl.ListCtrlAutoWidthMixin):
                 match = re.compile('.*%s.*' % text, re.I)
             else:
                 raise Exception('Unsupported filter type %s!' % filter_type)
-            self.values = [item for item in self.allvalues
-                    if Wammu.Utils.MatchesText(item, match, num)]
+            self.values = [
+                item for item in self.allvalues
+                if Wammu.Utils.MatchesText(item, match, num)
+            ]
         self.SetItemCount(len(self.values))
         self.RefreshView()
         self.ShowRow(0)
@@ -334,17 +368,17 @@ class Browser(wx.ListCtrl, wx.lib.mixins.listctrl.ListCtrlAutoWidthMixin):
         '''
         Compare function for internal list of values.
         '''
-        if self.sortkey == 'Location' and type(item1[self.sortkey]) == type(''):
+        if self.sortkey == 'Location' and isinstance(item1[self.sortkey], str):
             return self.sortorder * cmp(
                 int(item1[self.sortkey].split(',')[0]),
                 int(item2[self.sortkey].split(', ')[0]))
-        elif item1[self.sortkey] == None:
+        elif item1[self.sortkey] is None:
             return -self.sortorder
-        elif item2[self.sortkey] == None:
+        elif item2[self.sortkey] is None:
             return self.sortorder
         return self.sortorder * cmp(item1[self.sortkey], item2[self.sortkey])
 
-    def ShowLocation(self, loc, second = None):
+    def ShowLocation(self, loc, second=None):
         '''
         Shows row which is stored on defined location. Search can be extended
         by specifiyng second tupe of search attribute and value.
@@ -357,20 +391,23 @@ class Browser(wx.ListCtrl, wx.lib.mixins.listctrl.ListCtrlAutoWidthMixin):
         '''
         Activates id-th row.
         '''
-        if (self.GetItemCount() > index
-                and index >= 0
-                and self.GetCountPerPage() > 0):
+        if (self.GetItemCount() > index and index >= 0 and
+                self.GetCountPerPage() > 0):
             self.itemno = index
 
             while self.GetFirstSelected() != -1:
-                self.SetItemState(self.GetFirstSelected(), 0, wx.LIST_STATE_SELECTED)
+                self.SetItemState(
+                    self.GetFirstSelected(), 0, wx.LIST_STATE_SELECTED
+                )
 
-            self.SetItemState(index,
-                    wx.LIST_STATE_FOCUSED | wx.LIST_STATE_SELECTED,
-                    wx.LIST_STATE_FOCUSED | wx.LIST_STATE_SELECTED)
+            self.SetItemState(
+                index,
+                wx.LIST_STATE_FOCUSED | wx.LIST_STATE_SELECTED,
+                wx.LIST_STATE_FOCUSED | wx.LIST_STATE_SELECTED
+            )
             self.EnsureVisible(index)
         else:
-            evt = Wammu.Events.ShowEvent(data = None)
+            evt = Wammu.Events.ShowEvent(data=None)
             wx.PostEvent(self.win, evt)
 
     def Change(self, newtype, values):
@@ -378,10 +415,12 @@ class Browser(wx.ListCtrl, wx.lib.mixins.listctrl.ListCtrlAutoWidthMixin):
         Change type of browser component.
         '''
         if self.type != '':
-            self.cfg.Write('/BrowserSortKey/%s' % self.type,
-                    self.sortkey)
-            self.cfg.WriteInt('/BrowserSortOrder/%s' % self.type,
-                    self.sortorder)
+            self.cfg.Write(
+                '/BrowserSortKey/%s' % self.type, self.sortkey
+            )
+            self.cfg.WriteInt(
+                '/BrowserSortOrder/%s' % self.type, self.sortorder
+            )
         self.type = newtype
         self.values = values
         self.allvalues = values
@@ -433,7 +472,7 @@ class Browser(wx.ListCtrl, wx.lib.mixins.listctrl.ListCtrlAutoWidthMixin):
         self.SetColumnImage(col, image)
         self.RefreshView()
 
-        if item != None:
+        if item is not None:
             self.ShowRow(self.values.index(item))
 
     def RefreshView(self):
@@ -451,7 +490,6 @@ class Browser(wx.ListCtrl, wx.lib.mixins.listctrl.ListCtrlAutoWidthMixin):
             last = min(totalcount - 1, top + count)
             self.RefreshItems(top, last)
 
-
     def OnKey(self, evt):
         '''
         Key handler which catches delete key for deletion of current item and
@@ -477,21 +515,21 @@ class Browser(wx.ListCtrl, wx.lib.mixins.listctrl.ListCtrlAutoWidthMixin):
         '''
         Send delete event to parent.
         '''
-        evt = Wammu.Events.DeleteEvent(lst = lst)
+        evt = Wammu.Events.DeleteEvent(lst=lst)
         wx.PostEvent(self.win, evt)
 
     def DoBackup(self, lst):
         '''
         Send backup event to parent.
         '''
-        evt = Wammu.Events.BackupEvent(lst = lst)
+        evt = Wammu.Events.BackupEvent(lst=lst)
         wx.PostEvent(self.win, evt)
 
     def DoReply(self):
         '''
         Send reply event to parent.
         '''
-        evt = Wammu.Events.ReplyEvent(data = self.values[self.GetFocusedItem()])
+        evt = Wammu.Events.ReplyEvent(data=self.values[self.GetFocusedItem()])
         wx.PostEvent(self.win, evt)
 
     def OnRightClick(self, evt):
@@ -509,72 +547,71 @@ class Browser(wx.ListCtrl, wx.lib.mixins.listctrl.ListCtrlAutoWidthMixin):
         # add some items
         if self.popup_index != -1 and self.type == 'message':
             if self.values[evt.m_itemIndex]['State'] == 'Sent':
-                menu.Append(self.popup_id_send,       _('Resend'))
+                menu.Append(self.popup_id_send, _('Resend'))
             if self.values[evt.m_itemIndex]['State'] == 'UnSent':
-                menu.Append(self.popup_id_send,       _('Send'))
-            if (self.values[evt.m_itemIndex]['State'] == 'Read'
-                    or self.values[evt.m_itemIndex]['State'] == 'UnRead'):
-                menu.Append(self.popup_id_reply,      _('Reply'))
+                menu.Append(self.popup_id_send, _('Send'))
+            if self.values[evt.m_itemIndex]['State'] in ('Read', 'UnRead'):
+                menu.Append(self.popup_id_reply, _('Reply'))
             if self.values[evt.m_itemIndex]['Number'] != '':
-                menu.Append(self.popup_id_call,       _('Call'))
+                menu.Append(self.popup_id_call, _('Call'))
             menu.AppendSeparator()
 
         if self.popup_index != -1 and self.type in ['contact', 'call']:
-            menu.Append(self.popup_id_message,    _('Send message'))
-            menu.Append(self.popup_id_call,       _('Call'))
+            menu.Append(self.popup_id_message, _('Send message'))
+            menu.Append(self.popup_id_call, _('Call'))
             if self.popup_index != -1 and self.type in ['call']:
-                menu.Append(self.popup_id_contact,    _('Store as new contact'))
+                menu.Append(self.popup_id_contact, _('Store as new contact'))
             menu.AppendSeparator()
 
-        if self.popup_index != -1 and not self.type in ['call', 'message']:
-            menu.Append(self.popup_id_edit,       _('Edit'))
-        if self.popup_index != -1 and not self.type in ['call']:
-            menu.Append(self.popup_id_duplicate,  _('Duplicate'))
+        if self.popup_index != -1 and self.type not in ['call', 'message']:
+            menu.Append(self.popup_id_edit, _('Edit'))
+        if self.popup_index != -1 and self.type not in ['call']:
+            menu.Append(self.popup_id_duplicate, _('Duplicate'))
             menu.AppendSeparator()
 
         if self.popup_index != -1:
-            menu.Append(self.popup_id_delete,     _('Delete current'))
-        menu.Append(self.popup_id_delete_selection,  _('Delete selected'))
+            menu.Append(self.popup_id_delete, _('Delete current'))
+        menu.Append(self.popup_id_delete_selection, _('Delete selected'))
 
         menu.AppendSeparator()
         if self.popup_index != -1:
-            menu.Append(self.popup_id_backup_one,  _('Backup current'))
-        menu.Append(self.popup_id_backup_selection,  _('Backup selected'))
-        menu.Append(self.popup_id_backup_all,  _('Backup all'))
+            menu.Append(self.popup_id_backup_one, _('Backup current'))
+        menu.Append(self.popup_id_backup_selection, _('Backup selected'))
+        menu.Append(self.popup_id_backup_all, _('Backup all'))
 
         # Popup the menu.  If an item is selected then its handler
         # will be called before PopupMenu returns.
         self.PopupMenu(menu, evt.GetPoint())
 
     def OnPopupDuplicate(self, event):
-        evt = Wammu.Events.DuplicateEvent(data = self.values[self.popup_index])
+        evt = Wammu.Events.DuplicateEvent(data=self.values[self.popup_index])
         wx.PostEvent(self.win, evt)
 
     def OnPopupReply(self, event):
-        evt = Wammu.Events.ReplyEvent(data = self.values[self.popup_index])
+        evt = Wammu.Events.ReplyEvent(data=self.values[self.popup_index])
         wx.PostEvent(self.win, evt)
 
     def OnPopupSend(self, event):
-        evt = Wammu.Events.SendEvent(data = self.values[self.popup_index])
+        evt = Wammu.Events.SendEvent(data=self.values[self.popup_index])
         wx.PostEvent(self.win, evt)
 
     def OnPopupCall(self, event):
-        evt = Wammu.Events.CallEvent(data = self.values[self.popup_index])
+        evt = Wammu.Events.CallEvent(data=self.values[self.popup_index])
         wx.PostEvent(self.win, evt)
 
     def OnPopupMessage(self, event):
-        evt = Wammu.Events.MessageEvent(data = self.values[self.popup_index])
+        evt = Wammu.Events.MessageEvent(data=self.values[self.popup_index])
         wx.PostEvent(self.win, evt)
 
     def OnPopupContact(self, event):
         data = self.values[self.popup_index]
         data['Location'] = 0
         data['MemoryType'] = 'ME'
-        evt = Wammu.Events.EditEvent(data = data)
+        evt = Wammu.Events.EditEvent(data=data)
         wx.PostEvent(self.win, evt)
 
     def OnPopupEdit(self, event):
-        evt = Wammu.Events.EditEvent(data = self.values[self.popup_index])
+        evt = Wammu.Events.EditEvent(data=self.values[self.popup_index])
         wx.PostEvent(self.win, evt)
 
     def OnPopupDelete(self, event):
@@ -602,11 +639,11 @@ class Browser(wx.ListCtrl, wx.lib.mixins.listctrl.ListCtrlAutoWidthMixin):
 
     def OnItemSelected(self, event):
         self.itemno = event.m_itemIndex
-        evt = Wammu.Events.ShowEvent(data = self.values[event.m_itemIndex])
+        evt = Wammu.Events.ShowEvent(data=self.values[event.m_itemIndex])
         wx.PostEvent(self.win, evt)
 
     def OnItemActivated(self, event):
-        evt = Wammu.Events.EditEvent(data = self.values[event.m_itemIndex])
+        evt = Wammu.Events.EditEvent(data=self.values[event.m_itemIndex])
         wx.PostEvent(self.win, evt)
 
     def getColumnText(self, index, col):
