@@ -1,29 +1,26 @@
 # -*- coding: UTF-8 -*-
+#
+# Copyright © 2003 - 2015 Michal Čihař <michal@cihar.com>
+#
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published by
+# the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+#
 # vim: expandtab sw=4 ts=4 sts=4:
 '''
 Wammu - Phone manager
 Misc functions like charset conversion, entries parsers,..
 '''
-__author__ = 'Michal Čihař'
-__email__ = 'michal@cihar.com'
-__license__ = '''
-Copyright © 2003 - 2010 Michal Čihař
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License version 2 as published by
-the Free Software Foundation.
-
-This program is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
-more details.
-
-You should have received a copy of the GNU General Public License along with
-this program; if not, write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-'''
-
-import codecs
 import locale
 import sys
 import re
@@ -38,9 +35,10 @@ except ImportError:
     HAVE_GRP = False
 import Wammu.Locales
 from Wammu.Locales import StrConv
+from Wammu.Locales import ugettext as _
 
 import Wammu
-if Wammu.gammu_error == None:
+if Wammu.gammu_error is None:
     import gammu
 
 
@@ -68,10 +66,11 @@ def GetItemType(txt):
     else:
         return 'number'
 
-def SearchLocation(lst, loc, second = None):
+
+def SearchLocation(lst, loc, second=None):
     result = -1
     for i in range(len(lst)):
-        if second != None:
+        if second is not None:
             if not lst[i][second[0]] == second[1]:
                 continue
         if type(lst[i]['Location']) == type(loc):
@@ -84,6 +83,7 @@ def SearchLocation(lst, loc, second = None):
                 break
     return result
 
+
 def MatchesText(item, match, num):
     testkeys = ['Value', 'Text', 'Number']
     for x in item:
@@ -92,7 +92,7 @@ def MatchesText(item, match, num):
         else:
             val = x
         if type(val) in (str, unicode):
-            if match.search(val) != None:
+            if match.search(val) is not None:
                 return True
         elif num is not None and type(val) == int and num == val:
             return True
@@ -102,7 +102,7 @@ def MatchesText(item, match, num):
                     try:
                         val2 = val[i][key]
                         if type(val2) in (str, unicode):
-                            if match.search(val2) != None:
+                            if match.search(val2) is not None:
                                 return True
                         elif num is not None and type(val2) == int and num == val2:
                             return True
@@ -118,12 +118,13 @@ def SearchItem(lst, item):
             return i
     return -1
 
+
 def GrabNumberPrefix(number, prefixes):
     l = len(number)
     if l == 0 or number[0] != '+':
         return None
     i = 2
-    while not number[:i] in prefixes:
+    while number[:i] not in prefixes:
         i += 1
         if i > l:
             return None
@@ -134,6 +135,7 @@ NumberPrefix = ''
 
 NumberStrip = re.compile('^([#*]\d+[#*])?(\\+?.*)$')
 
+
 def NormalizeNumber(number):
     '''
     Attempts to create international number from anything it receives.
@@ -159,6 +161,7 @@ def NormalizeNumber(number):
         resnumber = NumberPrefix + resnumber
     return resnumber
 
+
 def SearchNumber(lst, number):
     for i in range(len(lst)):
         for x in lst[i]['Entries']:
@@ -166,16 +169,19 @@ def SearchNumber(lst, number):
                 return i
     return -1
 
+
 def GetContactLink(lst, i, txt):
     return StrConv('<a href="memory://%s/%d">%s</a> (%s)' % (lst[i]['MemoryType'], lst[i]['Location'], lst[i]['Name'], txt))
 
+
 def GetNumberLink(lst, number):
     i = SearchNumber(lst, number)
     if i == -1:
         return StrConv(number)
     return GetContactLink(lst, i, number)
 
-def GetTypeString(type, value, values, linkphone = True):
+
+def GetTypeString(type, value, values, linkphone=True):
     '''
     Returns string for entry in data dictionary. Formats it according to
     knowledge of format types.
@@ -203,7 +209,8 @@ def GetTypeString(type, value, values, linkphone = True):
     else:
         return StrConv(value)
 
-def ParseMemoryEntry(entry, config = None):
+
+def ParseMemoryEntry(entry, config=None):
     first = ''
     last = ''
     name = ''
@@ -238,7 +245,7 @@ def ParseMemoryEntry(entry, config = None):
         if i['Type'] == 'Number_General':
             number_result = i['Value']
         elif i['Type'][:7] == 'Number_':
-            number =  i['Value']
+            number = i['Value']
 
     if config is None:
         format = 'auto'
@@ -247,13 +254,13 @@ def ParseMemoryEntry(entry, config = None):
 
     if format == 'custom':
         name_result = config.Read('/Wammu/NameFormatString') % {
-                'Name' : name,
-                'FirstName' : first,
-                'LastName' : last,
-                'NickName' : nickname,
-                'FormalName' : formalname,
-                'Company' : company,
-                }
+            'Name': name,
+            'FirstName': first,
+            'LastName': last,
+            'NickName': nickname,
+            'FormalName': formalname,
+            'Company': company,
+        }
     else:
         if name != '':
             name_result = name
@@ -291,6 +298,7 @@ def ParseMemoryEntry(entry, config = None):
 
     return entry
 
+
 def ParseTodo(entry):
     dt = ''
     text = ''
@@ -311,6 +319,7 @@ def ParseTodo(entry):
     entry['Synced'] = False
     return entry
 
+
 def ParseCalendar(entry):
     start = ''
     end = ''
@@ -381,7 +390,8 @@ def ParseCalendar(entry):
     entry['Synced'] = False
     return entry
 
-def ParseMessage(msg, parseinfo = False):
+
+def ParseMessage(msg, parseinfo=False):
     txt = ''
     loc = ''
     msg['Folder'] = msg['SMS'][0]['Folder']
@@ -391,7 +401,7 @@ def ParseMessage(msg, parseinfo = False):
     msg['DateTime'] = msg['SMS'][0]['DateTime']
     if parseinfo:
         for i in msg['SMSInfo']['Entries']:
-            if i['Buffer'] != None:
+            if i['Buffer'] is not None:
                 txt = txt + i['Buffer']
     else:
         for i in msg['SMS']:
@@ -413,6 +423,7 @@ def ParseMessage(msg, parseinfo = False):
     msg['Synced'] = False
     return msg
 
+
 def ProcessMessages(list, synced):
     read = []
     unread = []
@@ -424,9 +435,9 @@ def ProcessMessages(list, synced):
         i = {}
         v = gammu.DecodeSMS(x)
         i['SMS'] = x
-        if v != None:
+        if v is not None:
             i['SMSInfo'] = v
-        ParseMessage(i, (v != None))
+        ParseMessage(i, (v is not None))
         i['Synced'] = synced
         if i['State'] == 'Read':
             read.append(i)
@@ -437,9 +448,15 @@ def ProcessMessages(list, synced):
         elif i['State'] == 'UnSent':
             unsent.append(i)
 
-    return {'read':read, 'unread':unread, 'sent':sent, 'unsent':unsent}
+    return {
+        'read': read,
+        'unread': unread,
+        'sent': sent,
+        'unsent': unsent
+    }
 
-def FormatError(txt, info, gammu_config = None):
+
+def FormatError(txt, info, gammu_config=None):
     if info['Code'] == gammu.Errors['ERR_NOTSUPPORTED']:
         message = _('Your phone doesn\'t support this function.')
     elif info['Code'] == gammu.Errors['ERR_NOTIMPLEMENTED']:
@@ -483,15 +500,17 @@ def FormatError(txt, info, gammu_config = None):
         message = '%s %s\n%s %s\n%s %d' % (_('Description:'), StrConv(info['Text']), _('Function:'), info['Where'], _('Error code:'), info['Code'])
     return StrConv(txt + '\n\n' + message)
 
+
 def FixupMaskedEdit(edit):
-        # XXX: this is not clean way of reseting to system colour, but I don't know better.
-        bgc = wx.SystemSettings.GetColour(wx.SYS_COLOUR_LISTBOX)
-        fgc = wx.SystemSettings.GetColour(wx.SYS_COLOUR_WINDOWTEXT)
-        setattr(edit, '_validBackgroundColour', bgc)
-        setattr(edit, '_foregroundColour', fgc)
+    # XXX: this is not clean way of reseting to system colour, but I don't know better.
+    bgc = wx.SystemSettings.GetColour(wx.SYS_COLOUR_LISTBOX)
+    fgc = wx.SystemSettings.GetColour(wx.SYS_COLOUR_WINDOWTEXT)
+    setattr(edit, '_validBackgroundColour', bgc)
+    setattr(edit, '_foregroundColour', fgc)
+
 
 def GetWebsiteLang():
-    (loc, charset) = locale.getdefaultlocale()
+    loc, charset = locale.getdefaultlocale()
     try:
         lang = loc[:2].lower()
         if lang in ('cs', 'de', 'es', 'fr', 'sk'):
@@ -500,19 +519,21 @@ def GetWebsiteLang():
     except TypeError:
         return ''
 
+
 def DBUSServiceAvailable(bus, interface, try_start_service=False):
     try:
         import dbus
     except ImportError:
         return False
-    if try_start_service:
-        try:
-            bus.start_service_by_name(interface)
-        except dbus.exceptions.DBusException:
-            print 'Failed to start DBus service %s' % interface
     obj = bus.get_object('org.freedesktop.DBus', '/org/freedesktop/DBus')
     dbus_iface = dbus.Interface(obj, 'org.freedesktop.DBus')
     avail = dbus_iface.ListNames()
+    if interface not in avail and try_start_service:
+        try:
+            bus.start_service_by_name(interface)
+            avail = dbus_iface.ListNames()
+        except dbus.exceptions.DBusException:
+            print 'Failed to start DBus service %s' % interface
     return interface in avail
 
 
@@ -549,7 +570,7 @@ def CheckDeviceNode(curdev):
                 _('Device %s does not exist!') % curdev
                 )
     if not os.access(curdev, os.R_OK) or not os.access(curdev, os.W_OK):
-        gid =  os.stat(curdev).st_gid
+        gid = os.stat(curdev).st_gid
         try:
             group = grp.getgrgid(gid)[0]
         except:
@@ -563,6 +584,7 @@ def CheckDeviceNode(curdev):
                 )
     return (0, '', '', '')
 
+
 def CompatConfig(cfg):
     '''
     Adjust configuration for possible changes in Gammu history.
